HighlightCategory

Enum HighlightCategory 

pub enum HighlightCategory {
Show 13 variants Attribute, Comment, Constant, Function, Keyword, Number, Operator, PunctuationBracket, PunctuationDelimiter, Property, String, Type, Variable,
}
Highlight category names used for default languages.

Variants



Attribute



Comment



Constant



Function



Keyword



Number



Operator



PunctuationBracket



PunctuationDelimiter



Property



String



Type



Variable

Implementations

Source

impl HighlightCategory

pub fn from_default_index(index: usize) -> Option<Self>

Map a default language highlight index to a category

pub fn from_typescript_index(index: usize) -> Option<Self>

Map a TypeScript highlight index to a category.

pub fn theme_key(&self) -> &'static str

Get the theme key path for this category (e.g., “syntax.keyword”).

pub fn display_name(&self) -> &'static str

Get a human-readable display name for this category.