pub enum HighlightCategory {
Show 13 variants
Attribute,
Comment,
Constant,
Function,
Keyword,
Number,
Operator,
PunctuationBracket,
PunctuationDelimiter,
Property,
String,
Type,
Variable,
}Expand description
Highlight category names used for default languages.
Variants
Attribute
Comment
Constant
Function
Keyword
Number
Operator
PunctuationBracket
PunctuationDelimiter
Property
String
Type
Variable
Implementations
Sourceimpl HighlightCategory
impl HighlightCategory
Sourcepub fn from_default_index(index: usize) -> Option<Self>
pub fn from_default_index(index: usize) -> Option<Self>
Map a default language highlight index to a category
Sourcepub fn from_typescript_index(index: usize) -> Option<Self>
pub fn from_typescript_index(index: usize) -> Option<Self>
Map a TypeScript highlight index to a category.
Sourcepub fn theme_key(&self) -> &'static str
pub fn theme_key(&self) -> &'static str
Get the theme key path for this category (e.g., “syntax.keyword”).
Sourcepub fn display_name(&self) -> &'static str
pub fn display_name(&self) -> &'static str
Get a human-readable display name for this category.